registerWith static method
Registers this class as the default instance of ScreenBrightnessProPlatform.
Implementation
static void registerWith(Registrar registrar) {
ScreenBrightnessProPlatform.instance = ScreenBrightnessProWeb();
}
Registers this class as the default instance of ScreenBrightnessProPlatform.
static void registerWith(Registrar registrar) {
ScreenBrightnessProPlatform.instance = ScreenBrightnessProWeb();
}